Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/indium/__init__.py | 9 | 0 | 0 | 100%
src/indium/_confusables.py | 2 | 0 | 0 | 100%
src/indium/_exceptions.py | 9 | 0 | 0 | 100%
src/indium/_grapheme_data.py | 21 | 0 | 0 | 100%
src/indium/_scripts_data.py | 2 | 0 | 0 | 100%
src/indium/_unicode_data.py | 30 | 2 | 0 | 93%
src/indium/invisibles.py | 50 | 0 | 0 | 100%
src/indium/segments.py | 135 | 2 | 0 | 99%
src/indium/spoofing.py | 72 | 4 | 0 | 94%
Total | 330 | 8 | 0 | 98%

No items found using the specified filter.